@@ -2,21 +2,15 @@
 
 import pathlib
 
-from NAME import VERSION
 from setuptools import find_packages, setup
 
 PROJECT_ROOT = pathlib.Path(__file__).parent
 README = (PROJECT_ROOT / 'README.md').read_text()
 
-ldap = ['freenit[ldap]']
-mongo = ['freenit[mongoengine]']
-sql = ['freenit[sql]']
-dev = ['freenit[dev]']
-
 setup(
     name='NAME',
-    version=VERSION,
-    description='REST API framework based on Flask-Smorest',
+    version='0.0.1',
+    description='REST API framework based on FastAPI',
     long_description=README,
     long_description_content_type='text/markdown',
     url='https://github.com/freenit-framework/backend',
@@ -24,33 +18,28 @@ setup(
     author_email='meka@tilda.center',
     license='BSD',
     classifiers=[
-        'Development Status :: 1 - Planning',
+        'Development Status :: 4 - Beta',
         'Intended Audience :: Developers',
         'Topic :: Internet :: WWW/HTTP',
         'Environment :: Web Environment',
-        'Framework :: Flask',
+        'Framework :: FastAPI',
         'License :: OSI Approved :: BSD License',
-        'Programming Language :: Python :: 3',
+        'Programming Language :: Python :: 3.8',
+        'Programming Language :: Python :: 3.9',
     ],
     keywords=[
         'REST',
         'openapi',
         'swagger',
-        'flask',
-        'marshmallow',
-        'apispec'
-        'webargs',
+        'fastapi',
     ],
     packages=find_packages(exclude=['tests*']),
-    python_requires='>=3.5',
-    install_requires=[
-        'freenit[DBTYPE]',
-    ],
+    python_requires='>=3.8',
+    install_requires=['freenit'],
     extras_require={
-        'all': ldap + mongo + sql,
-        'ldap': ldap,
-        'mongo': mongo,
-        'sql': sql,
-        'dev': dev,
+        'test': [
+            'pytest-asyncio',
+            'pytest-factoryboy',
+        ],
     },
 )
